==> apache-beam-2.14.0-source-release.zip: beam-release-2.14.0/website/src/community/in-person.md <==
---
layout: section
title: "Contact Us"
permalink: /community/in-person/
section_menu: section-menu/community.html
redirect_from:
  - /use/issue-tracking/
  - /use/mailing-lists/
  - /get-started/support/
---
<!--
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
-->

# We are nice, find us in person

While the official communication happens on the mailing list, and you can find us online (see: [contact-us](https://beam.apache.org/community/contact-us/)), we also get together in person at Meetups and Conferences.    

## Meetups

We occassionally meetup in various locations around the globe.  Active or to-be-started meetups include:

| Meetup City | Name |
| ----------------- | ---------------|
| Stockholm | [Apache Beam Stockholm](https://www.meetup.com/Apache-Beam-Stockholm/) |
| London | [London Apache Beam Meetup](https://www.meetup.com/London-Apache-Beam-Meetup/) |
| San Francisco | [Bay Area Apache Beam](https://www.meetup.com/San-Francisco-Apache-Beam/) |
| Los Angeles | [Los Angeles Apache Beam](https://www.meetup.com/Los-Angeles-Apache-Beam/) |
| Washington DC | [Washington DC Apache Beam Meetup](https://www.meetup.com/DC-Apache-Beam/) |
| New York City | [New York Apache Beam](https://www.meetup.com/New-York-Apache-Beam/) |:
{:.table}

The above are the meetups that are already known to the community (please add if you are organizing one!).  For Meetups that are tagged with 'Apache Beam', see the [list](https://www.meetup.com/topics/apache-beam/).


## Conference Talks
You can find a list [here](https://docs.google.com/spreadsheets/d/1CloF63FOKSPM6YIuu8eExjhX6xrIiOp5j4zPbSg3Apo/)

==> apache-beam-2.15.0-source-release.zip: beam-release-2.15.0/website/src/community/in-person.md <==
---
layout: section
title: "Contact Us"
permalink: /community/in-person/
section_menu: section-menu/community.html
redirect_from:
  - /use/issue-tracking/
  - /use/mailing-lists/
  - /get-started/support/
---
<!--
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
-->

# We are nice, find us in person

While the official communication happens on the mailing list, and you can find us online (see: [contact-us](https://beam.apache.org/community/contact-us/)), we also get together in person at Meetups and Conferences.    

## Meetups

We occasionally meet up in various locations around the globe. Active or to-be-started meetups include:

| Meetup City | Name |
| ----------------- | ---------------|
| Stockholm | [Apache Beam Stockholm](https://www.meetup.com/Apache-Beam-Stockholm/) |
| London | [London Apache Beam Meetup](https://www.meetup.com/London-Apache-Beam-Meetup/) |
| San Francisco | [Bay Area Apache Beam](https://www.meetup.com/San-Francisco-Apache-Beam/) |
| Los Angeles | [Los Angeles Apache Beam](https://www.meetup.com/Los-Angeles-Apache-Beam/) |
| Washington DC | [Washington DC Apache Beam Meetup](https://www.meetup.com/DC-Apache-Beam/) |
| New York City | [New York Apache Beam](https://www.meetup.com/New-York-Apache-Beam/) |:
{:.table}

The above are the meetups that are already known to the community (please add if you are organizing one!). For Meetups that are tagged with 'Apache Beam', see the [list](https://www.meetup.com/topics/apache-beam/).


## Conference Talks
You can find a list [here](https://docs.google.com/spreadsheets/d/1CloF63FOKSPM6YIuu8eExjhX6xrIiOp5j4zPbSg3Apo/)
